/*
 * GENERATED FILE, DO NOT EDIT. Generated by mkcast.py
 */
#include "config.h"
#include <inttypes.h>
#include <stddef.h>
#ifdef HAVE_SYS_TYPES_H
#include <sys/types.h>
#endif
void cast_assert(int must, const char* fmt, ...);
uint16_t cast_int16_uint16(int16_t from, const char* fmt, ...);
size_t cast_ssize_size(ssize_t from, const char* fmt, ...);
ssize_t cast_size_ssize(size_t from, const char* fmt, ...);
uint16_t cast_size_uint16(size_t from, const char* fmt, ...);
uint32_t cast_size_uint32(size_t from, const char* fmt, ...);
unsigned int cast_ulong_uint(unsigned long from, const char* fmt, ...);
int16_t cast_long_int16(long from, const char* fmt, ...);
uint8_t cast_int16_uint8(int16_t from, const char* fmt, ...);
unsigned int cast_int_uint(int from, const char* fmt, ...);
uint16_t cast_int_uint16(int from, const char* fmt, ...);
int cast_long_int(long from, const char* fmt, ...);
uint8_t cast_long_uint8(long from, const char* fmt, ...);
gid_t cast_ulong_gid(unsigned long from, const char* fmt, ...);
unsigned long long cast_longlong_ulonglong(long long from, const char* fmt, ...);
unsigned int cast_longlong_uint(long long from, const char* fmt, ...);
int16_t cast_int_int16(int from, const char* fmt, ...);
